# vizta

Talus themes for data visualization in Python.

See the documentation at https://TalusBio.github.io/vizta

## TLDR

```python
import vizta           # First import vizta

vizta.mpl.set_theme()  # Set the theme
make_plot()            # Then make the plot again
```
